{% load i18n %}<!doctype html>
<html>
<head>
<title>{% block title %}{{ META.title }}{% endblock %}</title>
<meta http-equiv="Content-Type" content="{% block content_type %}{{ META.content_type }}{% endblock content_type %}" /> 
{% block head_meta %}
<meta name="keywords" content="{{ META.keywords }}" />
<meta name="description" content="{{ META.description }}" />
<meta name="generator" content="{{ META.generator }}" />
{% if META.author %}
	<meta name="author" content="{{META.author}}" />
{% endif %}
{% if META.robots %}
	<meta name="robots" content="{{ META.robots }}" />
{% endif %}
<link href="/favicon.ico" rel="shortcut icon" type="image/x-icon" />
{% endblock head_meta %}
{% block head_media %}
<link rel="stylesheet" type="text/css" href="/upy_static/css/reset.css" />
{# <style type="text/css"></style> #}
 	{% for css in MEDIA_CSS %}
		<link rel="stylesheet" type="text/css" href="{{ css }}" />	
	{% endfor %}
	{% if USE_UPY_JQUERY_LIB %}
	<script type="text/javascript" src="{{JQUERY_LIB}}"></script>
	{% endif %}
	{% for js in MEDIA_JS_HEADER %}
		<script type="text/javascript" src="{{ js }}"></script> 	
	{% endfor %}
{% endblock head_media %}
{% block extra_head_media %}{% endblock %}
</head>
{% block tag_body %}
<body>
{% endblock %}
{% block body %}{% endblock %}

{% block foot_media %}
	{% for js in MEDIA_JS_FOOTER %}
		<script type="text/javascript" src="{{ js }}"></script> 	
	{% endfor %}
{% endblock foot_media %}
</body> 

</html>